@@ -3,7 +3,7 @@ from __future__ import annotations
 import contextlib
 import enum
 from functools import cached_property
-from typing import Any, Optional, Type
+from typing import Any, Generic, Optional, Type, TypeVar
 
 from attrs import define
 
@@ -11,7 +11,7 @@ from qtgql.codegen.py.compiler.builtin_scalars import BuiltinScalar
 from qtgql.codegen.py.runtime.bases import QGraphQListModel
 from qtgql.codegen.py.runtime.custom_scalars import BaseCustomScalar, CustomScalarMap
 from qtgql.codegen.utils import AntiForwardRef
-from qtgql.utils.typingref import TypeHinter
+from qtgql.utils.typingref import UNSET, TypeHinter
 
 
 class Kinds(enum.Enum):
@@ -26,14 +26,61 @@ class Kinds(enum.Enum):
 
 
 @define(slots=False)
-class GqlFieldDefinition:
+class QtGqlBaseTypedNode:
     name: str
     type: GqlTypeHinter
-    type_map: dict[str, GqlTypeDefinition]
+    type_map: dict[str, QtGqlObjectTypeDefinition]
     enums: EnumMap
     scalars: CustomScalarMap
+
+    @property
+    def is_custom_scalar(self) -> Optional[Type[BaseCustomScalar]]:
+        return self.type.is_custom_scalar(self.scalars)
+
+    @cached_property
+    def annotation(self) -> str:
+        """
+        :returns: Annotation of the field based on the real type,
+        meaning that the private attribute would be of that type.
+        this goes for init and the property setter.
+        """
+        return self.type.annotation(self.scalars)
+
+
+T = TypeVar("T")
+
+
+@define(slots=False)
+class QtGqlVariableDefinition(Generic[T], QtGqlBaseTypedNode):
+    default_value: Optional[T] = UNSET
+
+    def json_repr(self, attr_name: Optional[str] = None) -> str:
+        if not attr_name:
+            attr_name = self.name
+        if self.type.is_input_object_type:
+            return f"{attr_name}.asdict()"
+        elif self.type.is_builtin_scalar:
+            return attr_name
+        elif self.type.is_enum:
+            return f"{attr_name}.name"
+        elif self.is_custom_scalar:
+            return f"{attr_name}.{BaseCustomScalar.parse_value.__name__}()"
+
+        raise NotImplementedError(f"{self.type} is not supported as an input type ATM")
+
+
+@define(slots=False)
+class BaseQtGqlFieldDefinition(QtGqlBaseTypedNode):
     description: Optional[str] = ""
 
+
+@define(slots=False)
+class QtGqlInputFieldDefinition(BaseQtGqlFieldDefinition, QtGqlVariableDefinition):
+    ...
+
+
+@define(slots=False)
+class QtGqlFieldDefinition(BaseQtGqlFieldDefinition):
     @cached_property
     def default_value(self):
         if builtin_scalar := self.type.is_builtin_scalar:
@@ -55,25 +102,12 @@ class GqlFieldDefinition:
 
         return "None"  # Unions are not supported yet.
 
-    @property
-    def is_custom_scalar(self) -> Optional[Type[BaseCustomScalar]]:
-        return self.type.is_custom_scalar(self.scalars)
-
-    @cached_property
-    def annotation(self) -> str:
-        """
-        :returns: Annotation of the field based on the real type,
-        meaning that the private attribute would be of that type.
-        this goes for init and the property setter.
-        """
-        return self.type.annotation(self.scalars)
-
     @cached_property
     def fget_annotation(self) -> str:
         """This annotates the value that is QML-compatible."""
         if custom_scalar := self.type.is_custom_scalar(self.scalars):
             return TypeHinter.from_annotations(
-                custom_scalar.to_qt.__annotations__["return"]
+                custom_scalar.to_qt.__annotations__["return"],
             ).stringify()
         if self.type.is_enum:
             return "int"
@@ -120,7 +154,7 @@ class GqlFieldDefinition:
         return f"return self.{self.private_name}"
 
     @cached_property
-    def can_select_id(self) -> Optional[GqlFieldDefinition]:
+    def can_select_id(self) -> Optional[QtGqlFieldDefinition]:
         object_type = self.type.is_object_type
         if not object_type:
             if self.type.is_model:
@@ -130,24 +164,32 @@ class GqlFieldDefinition:
 
 
 @define(slots=False)
-class GqlTypeDefinition:
+class BaseGqlTypeDefinition:
     name: str
-    fields_dict: dict[str, GqlFieldDefinition]
+    fields_dict: dict[str, QtGqlFieldDefinition]
     docstring: Optional[str] = ""
 
+    @property
+    def fields(self) -> list[QtGqlFieldDefinition]:
+        return list(self.fields_dict.values())
+
+
+@define(slots=False)
+class QtGqlObjectTypeDefinition(BaseGqlTypeDefinition):
     @cached_property
-    def has_id_field(self) -> Optional[GqlFieldDefinition]:
+    def has_id_field(self) -> Optional[QtGqlFieldDefinition]:
         return self.fields_dict.get("id", None)
 
     @cached_property
-    def id_is_optional(self) -> Optional[GqlFieldDefinition]:
+    def id_is_optional(self) -> Optional[QtGqlFieldDefinition]:
         if id_f := self.has_id_field:
             if id_f.type.is_optional():
                 return id_f
 
-    @property
-    def fields(self) -> list[GqlFieldDefinition]:
-        return list(self.fields_dict.values())
+
+@define(slots=False)
+class QtGqlInputObjectTypeDefinition(BaseGqlTypeDefinition):
+    fields_dict: dict[str, QtGqlInputFieldDefinition] = {}  # type: ignore
 
 
 @define
@@ -159,12 +201,12 @@ class EnumValue:
 
 
 @define
-class GqlEnumDefinition:
+class QtGqlEnumDefinition:
     name: str
     members: list[EnumValue]
 
 
-EnumMap = dict[str, "GqlEnumDefinition"]
+EnumMap = dict[str, "QtGqlEnumDefinition"]
 
 
 def optional_maybe(th: GqlTypeHinter) -> GqlTypeHinter:
@@ -181,14 +223,20 @@ class GqlTypeHinter(TypeHinter):
         self.of_type: tuple[GqlTypeHinter, ...] = of_type
 
     @property
-    def is_object_type(self) -> Optional[GqlTypeDefinition]:
+    def is_object_type(self) -> Optional[QtGqlObjectTypeDefinition]:
         t_self = optional_maybe(self).type
         with contextlib.suppress(TypeError):
             if issubclass(t_self, AntiForwardRef):
                 ret = t_self.resolve()
-                if isinstance(ret, GqlTypeDefinition):
+                if isinstance(ret, QtGqlObjectTypeDefinition):
                     return ret
 
+    @property
+    def is_input_object_type(self) -> Optional[QtGqlInputObjectTypeDefinition]:
+        t_self = optional_maybe(self).type
+        if isinstance(t_self, QtGqlInputObjectTypeDefinition):
+            return t_self
+
     @property
     def is_model(self) -> Optional[GqlTypeHinter]:
         t_self = optional_maybe(self)
@@ -197,11 +245,11 @@ class GqlTypeHinter(TypeHinter):
             return t_self.of_type[0]
 
     @property
-    def is_enum(self) -> Optional[GqlEnumDefinition]:
+    def is_enum(self) -> Optional[QtGqlEnumDefinition]:
         t_self = optional_maybe(self).type
         with contextlib.suppress(TypeError):
             if issubclass(t_self, AntiForwardRef):
-                if isinstance(t_self.resolve(), GqlEnumDefinition):
+                if isinstance(t_self.resolve(), QtGqlEnumDefinition):
                     return t_self.resolve()
 
     @property
@@ -232,14 +280,15 @@ class GqlTypeHinter(TypeHinter):
             return f"SCALARS.{scalar.__name__}"
         if gql_enum := t_self.is_enum:
             return gql_enum.name
-        # handle Optional, Union, List etc...
-        # removing redundant prefixes.
         if model_of := t_self.is_model:
             return f"{QGraphQListModel.__name__}[{model_of.annotation(scalars)}]"
         if object_def := t_self.is_object_type:
             return f"Optional[{object_def.name}]"
         if t_self.is_union():
             return "Union[" + ", ".join(th.annotation(scalars) for th in t_self.of_type) + "]"
+        if input_obj := t_self.is_input_object_type:
+            return input_obj.name
+
         raise NotImplementedError  # pragma no cover
 
     def as_annotation(self, object_map=None):  # pragma: no cover
